.. image:: https://img.shields.io/pypi/v/slurry.svg
   :target: https://pypi.org/project/slurry
   :alt: Latest PyPi version

.. image:: https://travis-ci.com/andersea/slurry.svg?branch=master
   :target: https://travis-ci.com/andersea/slurry
   :alt: Build Status

Slurry - An async stream processing microframework
==================================================